@@ -65,7 +65,6 @@ class Resolution(NamedTuple):
             for file in files:
                 path = file["path"]
                 file["path"] = utils.remove_test_data_dir_variable_prefix(path=path)
-
         return {
             "files": files,
             "packages": [package for package in self.packages],
@@ -90,6 +89,7 @@ def resolve_dependencies(
     prefer_source=False,
     printer=print,
     generic_paths=False,
+    ignore_errors=False,
 ):
     """
     Resolve the dependencies for the package requirements listed in one or
@@ -154,6 +154,7 @@ def resolve_dependencies(
         deps = dependencies.get_dependencies_from_requirements(requirements_file=req_file)
         for extra_data in dependencies.get_extra_data_from_requirements(requirements_file=req_file):
             index_urls = (*index_urls, *tuple(extra_data.get("extra_index_urls") or []))
+            index_urls = (*index_urls, *tuple(extra_data.get("index_url") or []))
         direct_dependencies.extend(deps)
         package_data = [
             pkg_data.to_dict() for pkg_data in PipRequirementsFileHandler.parse(location=req_file)
@@ -284,6 +285,7 @@ def resolve_dependencies(
         max_rounds=max_rounds,
         pdt_output=pdt_output,
         analyze_setup_py_insecurely=analyze_setup_py_insecurely,
+        ignore_errors=ignore_errors,
     )
 
     packages = []
@@ -321,6 +323,7 @@ def resolve(
     max_rounds=200000,
     pdt_output=False,
     analyze_setup_py_insecurely=False,
+    ignore_errors=False,
 ):
     """
     Resolve dependencies given a ``direct_dependencies`` list of
@@ -346,6 +349,7 @@ def resolve(
         max_rounds=max_rounds,
         pdt_output=pdt_output,
         analyze_setup_py_insecurely=analyze_setup_py_insecurely,
+        ignore_errors=ignore_errors,
     )
 
     return resolved_dependencies, packages
@@ -359,6 +363,7 @@ def get_resolved_dependencies(
     max_rounds: int = 200000,
     pdt_output: bool = False,
     analyze_setup_py_insecurely: bool = False,
+    ignore_errors: bool = False,
 ):
     """
     Return resolved dependencies of a ``requirements`` list of Requirement for
@@ -373,6 +378,7 @@ def get_resolved_dependencies(
             environment=environment,
             repos=repos,
             analyze_setup_py_insecurely=analyze_setup_py_insecurely,
+            ignore_errors=ignore_errors,
         ),
         reporter=BaseReporter(),
     )
